==> apache-geode-native-1.13.8-src.tgz: apache-geode-native-1.13.8-src/cppcache/src/ResultSetImpl.hpp <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#pragma once

#ifndef GEODE_RESULTSETIMPL_H_
#define GEODE_RESULTSETIMPL_H_

#include <memory>

#include <geode/CacheableBuiltins.hpp>
#include <geode/ResultSet.hpp>
#include <geode/internal/geode_globals.hpp>

namespace apache {
namespace geode {
namespace client {

class APACHE_GEODE_EXPORT ResultSetImpl : public ResultSet {
 public:
  explicit ResultSetImpl(const std::shared_ptr<CacheableVector>& response);
  ~ResultSetImpl() noexcept override = default;

  size_t size() const override;

  const std::shared_ptr<Serializable> operator[](size_t index) const override;

  SelectResults::iterator begin() override;

  SelectResults::iterator end() override;

 private:
  std::shared_ptr<CacheableVector> m_resultSetVector;
};

}  // namespace client
}  // namespace geode
}  // namespace apache

#endif  // GEODE_RESULTSETIMPL_H_

==> apache-geode-native-1.15.1-src.tgz: apache-geode-native-1.15.1-src/cppcache/src/ResultSetImpl.hpp <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#pragma once

#ifndef GEODE_RESULTSETIMPL_H_
#define GEODE_RESULTSETIMPL_H_

#include <memory>

#include <geode/CacheableBuiltins.hpp>
#include <geode/ResultSet.hpp>
#include <geode/internal/geode_globals.hpp>

namespace apache {
namespace geode {
namespace client {

class ResultSetImpl : public ResultSet {
 public:
  explicit ResultSetImpl(const std::shared_ptr<CacheableVector>& response);
  ~ResultSetImpl() noexcept override = default;

  size_t size() const override;

  const std::shared_ptr<Serializable> operator[](size_t index) const override;

  SelectResults::iterator begin() override;

  SelectResults::iterator end() override;

 private:
  std::shared_ptr<CacheableVector> m_resultSetVector;
};

}  // namespace client
}  // namespace geode
}  // namespace apache

#endif  // GEODE_RESULTSETIMPL_H_
